@@ -17,7 +17,7 @@ pub use self::{
     records::{
         builder::ASTBuilder,
         cst_node::CSTNode,
-        text_index::{line_column::TextAdaptor, Position, TextChange, TextIndex},
+        text_index::{line_column::TextAdaptor, Offset, OffsetRange, Position, PositionRange, TextChange, TextIndex},
     },
     traits::{
         ast_node::ASTNode,
@@ -26,6 +26,6 @@ pub use self::{
 };
 
 #[cfg(feature = "lsp-types")]
-pub use self::records::text_index::lsp::LspTextAdaptor;
+pub use {self::records::text_index::lsp::LspTextAdaptor, lsp_types::Position as LspPosition, lsp_types::Range as LspRange};
 
 pub use url::Url;
